==> wiki3_4_3.zip: wiki3_4_3/plugin/recent/RecentDays.pm <==
############################################################
# 
# Ƕṹ줿ڡդȤ˰ɽޤ
# ɽꤷޤ
# <pre>
# {{recentdays 10}}
# </pre>
# ά5ʬϤޤ
# 
############################################################
package plugin::recent::RecentDays;
#use strict;
use plugin::recent::RecentCache;
#===========================================================
# 󥹥ȥ饯
#===========================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#===========================================================
# 饤᥽å
#===========================================================
sub inline {
	my $self = shift;
	my $wiki = shift;
	my $max  = shift;
	my $cgi  = $wiki->get_CGI;

	my $cachefile = $wiki->config('log_dir')."/recent.cache";
	if (-e $cachefile) {
		
	} else {
		&plugin::recent::RecentCache::update_cache($wiki);
	}

	my $buf = &Util::load_config_text(undef, $cachefile);
	my @lines = split(/\n/, $buf);
	
	if($max eq ""){
	    $max = 5;
	}
	
	my $content = "";
	my $count = 0;
	
	my $l_year = 0;
	my $l_mon  = 0;
	my $l_day  = 0;
	
	foreach my $line (@lines){
	    my @keys = split(/\t/, $line);
	    my $page = $keys[0];
	    my $modtime = $keys[1];
	    my ($sec, $min, $hour, $mday, $mon, $year, $wday) = localtime($modtime);
	    $year += 1900;
	    $mon  += 1;
	    if($l_year!=$year || $l_mon!=$mon || $l_day!=$mday){
		if($count==$max){
		    last;
		}
		if($content ne ""){
		    $content .= "</ul>\n";
		}
		$content .= "<p><b>$year/$mon/$mday</b></p>\n<ul>\n";
		$l_year = $year;
		$l_mon  = $mon;
		$l_day  = $mday;
		$count++;
	    }
	    $content .= "<li><a href=\"".$wiki->config('script_name')."?page=".Util::url_encode($page)."\">".Util::escapeHTML($page)."</a></li>\n";
	}
	if($content ne ""){
	    $content .= "</ul>\n";
	}
	return $content;
}

1;

==> wiki3_5_0.zip: wiki3_5_0/plugin/recent/RecentDays.pm <==
############################################################
# 
# Ƕṹ줿ڡդȤ˰ɽޤ
# ɽꤷޤ
# <pre>
# {{recentdays 10}}
# </pre>
# ά5ʬϤޤ
# 
############################################################
package plugin::recent::RecentDays;
#use strict;
use plugin::recent::RecentCache;
#===========================================================
# 󥹥ȥ饯
#===========================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#===========================================================
# ѥ饰ե᥽å
#===========================================================
sub paragraph {
	my $self   = shift;
	my $wiki   = shift;
	my $max    = shift;
	my $cgi    = $wiki->get_CGI;

	my $cachefile = $wiki->config('log_dir')."/recent.cache";
	if (-e $cachefile) {
		
	} else {
		&plugin::recent::RecentCache::update_cache($wiki);
	}

	my $buf = &Util::load_config_text(undef, $cachefile);
	my @lines = split(/\n/, $buf);
	
	if($max eq ""){
		$max = 5;
	}
	
	my $content = "";
	my $count   = 0;
	
	my $l_year = 0;
	my $l_mon  = 0;
	my $l_day  = 0;
	
	foreach my $line (@lines){
		my @keys = split(/\t/, $line);
		my $page = $keys[0];
		my $modtime = $keys[1];
		my ($sec, $min, $hour, $mday, $mon, $year, $wday) = localtime($modtime);
		$year += 1900;
		$mon  += 1;
		if($l_year!=$year || $l_mon!=$mon || $l_day!=$mday){
			if($count==$max){
			    last;
			}
			$content .= "'''$year/$mon/$mday'''\n";
			$l_year = $year;
			$l_mon  = $mon;
			$l_day  = $mday;
			$count++;
		}
		$content .= "*[[$page]]\n";
	}
	
	return $content;
}

1;
